==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-open/i18n/lumina-open_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Otwórz za pomocą...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Preferowany</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Własny</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Położenie pliku binarnego</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Wyszukaj</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Ustaw aplikację jako domyślną </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Zaniechaj</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Odnośnik email)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(Internet URL - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Narzędzia programistów</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Edukacja</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Nauka</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Znajdź plik binarny aplikacji</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Błąd pliku</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Głośność dźwięku %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Jasność ekranu %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Nieprawidłowy plik lub URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>File could not be opened: %1</source>
        <translation>Nie można otworzyć pliku: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Skrót do aplikacji nie posiada odpowiednich informacji do uruchomienia (niewłaściwy skrót): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>W skrócie URL brak adresu URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>W skrócie do folderu brak ścieżki do folderu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Nieznany błąd skrótu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Binary Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>Application Error</source>
        <translation>Błąd aplikacji</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>Aplikacja napotkała błąd i musi zostać zamknięta:</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core/lumina-open/i18n/lumina-open_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Otwórz za pomocą...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Preferowany</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Dostępny</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Własny</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Położenie pliku binarnego</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Wyszukaj</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Ustaw aplikację jako domyślną </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Zaniechaj</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Odnośnik email)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(Internet URL - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Wideo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Narzędzia programistów</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Edukacja</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Gra</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Grafika</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Biuro</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Nauka</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Znajdź plik binarny aplikacji</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Błąd pliku</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Głośność dźwięku %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Jasność ekranu %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Nieprawidłowy plik lub URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Skrót do aplikacji nie posiada odpowiednich informacji do uruchomienia (niewłaściwy skrót): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>W skrócie URL brak adresu URL: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>W skrócie do folderu brak ścieżki do folderu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Nieznany błąd skrótu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Binary Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>Nie można znaleźć &quot;%1&quot;. Upewnij się, że jest zainstalowany.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>Application Error</source>
        <translation>Błąd aplikacji</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>Aplikacja napotkała błąd i musi zostać zamknięta:</translation>
    </message>
</context>
</TS>
